@@ -3,12 +3,13 @@ Main interface for sagemaker-a2i-runtime service.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.sagemaker_a2i_runtime import (
+    from mypy_boto3_sagemaker_a2i_runtime import (
         AugmentedAIRuntimeClient,
         Client,
         ListHumanLoopsPaginator,
-        )
+    )
 
     session = boto3.Session()
 
@@ -16,10 +17,11 @@ Usage::
     session_client: AugmentedAIRuntimeClient = session.client("sagemaker-a2i-runtime")
 
     list_human_loops_paginator: ListHumanLoopsPaginator = client.get_paginator("list_human_loops")
+    ```
 """
 from mypy_boto3_sagemaker_a2i_runtime.client import (
-    AugmentedAIRuntimeClient as Client,
     AugmentedAIRuntimeClient,
+    AugmentedAIRuntimeClient as Client,
 )
 from mypy_boto3_sagemaker_a2i_runtime.paginator import ListHumanLoopsPaginator
 
